pub enum AtomError {
OutOfRange(usize),
InvalidBond(usize, usize),
InvalidSimBox(SimBoxError),
InvalidPosition(PositionError),
InvalidMass(MassError),
}Expand description
Errors that can occur when working with atoms in a system.
Variants
OutOfRange(usize)
Used when selecting an atom from the system with invalid atom index.
InvalidBond(usize, usize)
Used when attempting to create a bond that is invalid.
InvalidSimBox(SimBoxError)
Used when there is an issue with simulation box of the system.
InvalidPosition(PositionError)
Used when there is an issue with position of an atom.
InvalidMass(MassError)
Used when there is an issue with masses of atoms in the system.