pub enum ParseElementError {
FileNotFound(Box<Path>),
FileCouldNotBeRead(Box<Path>),
CouldNotParseYaml(Error),
DuplicateSymbol(String, String, String),
}Expand description
Errors that can occur when reading element data.
Variants
FileNotFound(Box<Path>)
Used when the yaml file was not found (i.e. does not exist).
FileCouldNotBeRead(Box<Path>)
Used when the content of the yaml file could not be read.
CouldNotParseYaml(Error)
Used when the yaml string containing element data can’t be parsed.
DuplicateSymbol(String, String, String)
Used when the same element symbol corresponds to multiple elements.