pub enum WriteNdxError {
CouldNotCreate(Box<Path>),
CouldNotWrite,
}Expand description
Errors that can occur when writing an ndx file.
Variants
CouldNotCreate(Box<Path>)
Used when the ndx file could not be opened for writing (i.e. path is invalid).
CouldNotWrite
Used when writing into the ndx file failed for any reason.